# Einführung in Proxmox

## Was ist Proxmox

Proxmox ist eine leistungsstarke und vielseitige Virtualisierungsplattform. Sie können sie verwenden, um virtuelle Maschinen und Container zu erstellen und zu verwalten. Mit einer integrierten Web-Benutzeroberfläche ist sie benutzerfreundlich und ermöglicht die einfache Konfiguration und Verwaltung Ihrer virtuellen Umgebungen. Speicher-, Update- und andere Funktionen sind direkt eingebaut, sodass Sie den vollen Funktionsumfang direkt aus der Box nutzen können.

## Was Sie benötigen, um anzufangen

Um Proxmox zu verwenden, benötigen Sie zunächst einen Server, der in der Lage ist, die Software auszuführen. Dies kann ein physischer Server, ein virtueller Server oder eine Cloud-Instanz sein. Ihre CPU muss Virtualisierung unterstützen und sollte ein 64-Bit-Prozessor sein. Das absolute Minimum an RAM für die Ausführung von Proxmox ist 1 GB, aber für den praktischen Einsatz werden oft mehr benötigt. Sie sollten auch den schnellsten Speicher verwenden, auf den Sie Zugriff haben, um die bestmögliche Performance zu erzielen. Eine Netzwerkkarte ist ebenfalls erforderlich, um Ihre virtuellen Maschinen und Container mit dem Netzwerk zu verbinden.

## Was kostet Proxmox

Proxmox selbst ist kostenlos. Sie können die Software herunterladen und auf Ihrem Server installieren, ohne Lizenzgebühren zu zahlen. Wenn Sie jedoch zusätzlichen Support benötigen, können Sie diesen erwerben. Der Erwerb von Support für Proxmox bietet auch Zugang zum Enterprise Repository, das zusätzliche Funktionen und Verbesserungen bietet.

## Wo können Sie Hilfe bekommen

Wenn Sie auf Probleme stoßen oder Fragen zur Verwendung von Proxmox haben, gibt es verschiedene Ressourcen, die Sie nutzen können. Das [Proxmox Wiki](https://pve.proxmox.com/wiki) bietet eine Fülle von Informationen und Anleitungen zur Verwendung der Software. Die [Proxmox-Community](https://forum.proxmox.com) ist auch ein ausgezeichneter Ort, um Hilfe zu suchen. Sie können Fragen im Forum stellen und von der Erfahrung und dem Wissen anderer Proxmox-Benutzer profitieren.\
Eine weitere Quelle wäre die [Anleitung](https://technotim.live/categories/proxmox/) des YouTubers Techno-Tim.

# Installationsprozess

-   Laden Sie zunächst das [Proxmox Virtual Environment](https://www.proxmox.com/de/downloads) (auch als Proxmox VE bezeichnet) herunter.

-   Erstellen Sie einen bootfähigen USB-Stick mit Hilfe eines USB-Imager-Tools wie z.B. [Rufus](https://rufus.ie/de/) oder [Balena Etcher](https://etcher.balena.io/)

-   Schalten Sie das Gerät aus und booten Sie in die BIOS-Einstellungen

-   Stellen Sie sicher, dass Secure-Boot deaktiviert und die Virtualisierung aktiviert ist

-   Booten Sie von Proxmox Bei der Installation haben Sie zwei Möglichkeiten:

-   UI-Installation (empfohlen)

-   Konsolenbasierte Installation

-   Akzeptieren Sie die EULA (END USER LICENSE AGREEMENT)

-   Wählen Sie die Festplatte aus, auf der das Betriebssystem installiert werden soll

-   Unter dem Button "Optionen" können Sie weitere Installationsmöglichkeiten auswählen Wählen Sie das passende Dateisystem:

> [!INFO]+
>
> -   **Ext4:** Wenn Sie alles auf ==einer Festplatte== installieren möchten
> -   **XFS:** Wenn für Sie eine ==50 TiB== Festplatte ==nicht ausreicht==
> -   **ZFS:** Wenn Sie ==mehr als 32 GB RAM== zur Verfügung haben und das System auf mehreren Festplatten installieren möchten
> -   **BTRFS:** Vor allem, wenn Sie ==Timeshift== nutzen möchten

-   Stellen Sie sicher, dass die Zeitzone sowie das Tastaturlayout korrekt eingestellt sind
-   Erstellen Sie ein sicheres Passwort und geben Sie, falls Sie später Support benötigen, Ihre korrekte E-Mail-Adresse an
-   Bei der MNC (Management Network Configuration) können Sie die Netzwerkkarte auswählen, über die Proxmox erreichbar sein soll
-   Mit dem Hostnamen können Sie den Namen eingeben, unter dem das Gerät erreichbar sein soll
-   Ein wenig weiter haben Sie die Optionen für die IP-Adresse (falls Sie bereits einen DHCP-Server haben, werden einige Einstellungen bereits vorgeschlagen). Wählen Sie die passende IP-Adresse und das richtige Subnetz, sowie das Gateway und den DNS-Server.
-   Danach sollten Sie einen vollständigen Überblick über die gesamte Konfiguration haben.
-   Nach der Installation sollte der Server automatisch neu starten. Nun sollten Sie Ihren Proxmox-Server unter der vergebenen IP-Adresse mit einem HTTPS-Protokoll auf Port 8006 finden.

Die Eingabe sollte ungefähr so aussehen: [https://10.0.0.10:8006](https://wiki.zenndev.xyz/de/zzzEgor/Proxmox/Guide_DE)

-   Der Browser sollte eine automatische Fehlermeldung anzeigen. Keine Sorge, es ist nichts Gefährliches. Klicken Sie auf `Erweitert` -> `Risiko akzeptieren und fortfahren`.
-   Melden Sie sich an: Der Benutzername sollte "root" sein und das Passwort ist das, das Sie zuvor festgelegt haben.

# Übersicht über die Web-Konsole

Für eine genauere Übersicht über die Web-UI, schauen Sie sich folgendes [Video](https://www.youtube.com/watch?v=1PGRpx7xgmo&list=PLT98CRl2KxKHnlbYhtABg6cF50bYa8Ulo&index=3) an.

# Erste Schritte nach der Installation

## Update Repo aktualisieren

-   Unter `pve` -> `Updates` -> `Repositories`:
    -   pve-enterprise repo deaktivieren
    -   ceph-quincy enterprise repo deaktivieren
    -   No-Subscription repo hinzufügen
    -   Ceph Quincy No-Subscription repo hinzufügen
-   Um die deaktivierte Repositories endgültig zu löschen gehen Sie ins Terminal und fügen Sie folgendes ein:

```
cd /etc/apt/sources.list.d
rm ceph.list pve-enterprise.list
cd /root
```

Führen Sie ein Update durch. Mit folgendem Befehl können Sie das System updaten, upgraden und neustarten (dies braucht es manchmal, um die alte Pakete zu deinstallieren und neue zu installieren)

```
apt update -y && apt upgrade -y && reboot
```

Nach dem Reboot stellen Sie sicher, dass alle unwichtige/ungenutzte Pakete gelöscht werden:

```
apt autoremove
```

## Meldung 'No Valid Subscription' entfernen

-   Wechseln Si ein das Arbeitsverzeichnis\
    `cd /usr/share/javascript/proxmox-widget-toolkit`

-   Erstellen Sie eine Sicherungskopie\
    `cp proxmoxlib.js proxmoxlib.js.bak`

-   Bearbeiten Sie die Datei\
    `nano proxmoxlib.js`

-   Suchen Sie den folgenden Code

```
Ext.Msg.show({
title: gettext('No valid subscription'),
```

> [!Tipp]+\
> Verwenden Sie CTRL+W in Nano und suchen Sie nach "No valid subscription"

Ersetzen Sie "Ext.Msg.show" durch "void", danach soll es ca. so aussehen:

```
void({ //Ext.Msg.show({
title: gettext('No valid subscription'),
```

-   Starten Sie den Proxmox Web-Service neu\
    `systemctl restart pveproxy.service`

> [!Info]\
> Vergewissern Sie sich, dass Sie den Cache Ihres Web-Browsers löschen, möglicherweise müssen Sie Ihren Browser neu starten

-   Um zu überprüfen, ob die Änderung vorgenommen wurde:

```
grep -n -B 1 'No valid sub' proxmoxlib.js
```

## Vergrößern Sie die lokale Festplatte auf die volle Kapazität

> [!info]
>
> -   nur, wenn Sie mehr als ein Laufwerk haben
> -   sehr nützlich für mehr Speicher auf dem Hauptlaufwerk

-   Unter `Datacenter` -> `Storage`: löschen Sie die local-lvm Partitionen

Mit Folgendem Befehl löschen Sie die local-lvm Partition vollständig:

```
lvremove /dev/pve/data -y
```

Vergrößern der Haupt-Partition:

```
lvresize -l +100%FREE /dev/pve/root
resize2fs /dev/mapper/pve-root
```

## Speicher

Wenn Sie Speicher haben, auf dem Partitionen vorhanden sind und Sie diese löschen wollen:

```
fdisk /dev/sda
```

Dort können Sie angeben, welche Disk Sie auswählen wollen und danach können Sie mit:

-   **_P_** -> Partition auflisten
-   **_D_** -> Löschen
-   **_W_** -> Schreiben

## SMART Monitoring überprüfen

```
smartctl -a /dev/sda
```

## IOMMU (PCI Passthrough)

```
nano /etc/kernel/cmdline
```

Fügen Sie _intel_iommu=on iommu=pt_ am Ende dieser Zeile ohne Zeilenumbrüche hinzu

```
root=ZFS=rpool/ROOT/pve-1 boot=zfs intel_iommu=on iommu=pt
```

Bearbeiten Sie _/etc/modules_

```
vfio
vfio_iommu_type1
vfio_pci
vfio_virqfd
```

Führen Sie folgendes aus:

```
update-initramfs -u -k all
```

Damit die Einstellungen in Kraft treten, muss man das Gerät neu starten

```
reboot
```

# VMs oder Container?

# Starten von virtuellen Maschinen

# Erstellen von VM-Vorlagen

# Starten von Containern

# Erstellen von Container-Vorlagen

# Verwaltung von Benutzern

# Backups und Snapshots

# Integrierte Firewall

# Befehlszeilenschnittstelle

# Netzwerk

# Gemeinsam genutzter Speicher

# Clustering

# [¶](https://wiki.zenndev.xyz/de/zzzEgor/Proxmox/Guide_DE#hochverfügbarkeit-high-availability-ha) Hochverfügbarkeit (High Availability / HA)
